@@ -132,6 +132,8 @@ class Cassandra(object):
                                               'log4j.appender.R.File=%s' % logpath,
                                               src.read())
                             dest.write(property)
+                elif os.path.isdir(srcpath):
+                    copytree(srcpath, destpath)
                 else:
                     copyfile(srcpath, destpath)
 
@@ -233,7 +235,7 @@ class Cassandra(object):
             return
 
         from shutil import rmtree
-        if self._use_tmpdir:
+        if self._use_tmpdir and os.path.exists(self.base_dir):
             rmtree(self.base_dir)
 
     def read_log(self):
